@@ -26,6 +26,8 @@
 #undef ARCH_ALIGN_DOUBLE
 #undef ARCH_ALIGN_INT64
 #define ASM_CFI_SUPPORTED
+#define PROFINFO_WIDTH 26
+#define CAML_WITH_CPLUGINS
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/lib/ocaml"
 #define POSIX_SIGNALS
@@ -54,6 +56,7 @@
 #define HAS_TRUNCATE
 #define HAS_SYS_SELECT_H
 #define HAS_SELECT
+#define HAS_NANOSLEEP
 #define HAS_SYMLINK
 #define HAS_WAITPID
 #define HAS_WAIT4
